@@ -1,8 +1,8 @@
-/*  $Id: EnemySprite.cpp,v 1.7 2009/02/27 02:50:42 sarrazip Exp $
+/*  $Id: EnemySprite.cpp,v 1.6.2.5 2010/05/09 01:18:46 sarrazip Exp $
     EnemySprite.cpp - Sprite that represents an enemy of the player.
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2001-2009 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2010 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,12 +28,14 @@ using namespace flatzebra;
 
 
 EnemySprite::EnemySprite(const PixmapArray &pa,
-			    Couple pos, Couple speed,
-			    Couple collBoxPos, Couple collBosSize) throw(int)
+                            Couple pos, Couple speed,
+                            Couple collBoxPos, Couple collBosSize) throw(int)
   : Sprite(pa, pos, speed, Couple(0, 0), collBoxPos, collBosSize),
     carryingGroup(NULL),
     disappearanceTime(0),
-    timeToDie(0)
+    timeToDie(0),
+    lastDirection(-1),
+    climbingFromPlate(false)
 {
 }
 
@@ -48,3 +50,31 @@ EnemySprite::setCarryingGroup(IngredientGroup *g)
 {
     carryingGroup = g;
 }
+
+
+void
+EnemySprite::setLastDirection(int dir)
+{
+    lastDirection = dir;
+}
+
+
+int
+EnemySprite::getLastDirection() const
+{
+    return lastDirection;
+}
+
+
+void
+EnemySprite::setClimbingFromPlate(bool climbing)
+{
+    climbingFromPlate = climbing;
+}
+
+
+bool
+EnemySprite::isClimbingFromPlate() const
+{
+    return climbingFromPlate;
+}
