@@ -1,8 +1,8 @@
-/*  $Id: IngredientGroup.h,v 1.12 2009/02/27 02:50:42 sarrazip Exp $
+/*  $Id: IngredientGroup.h,v 1.11.2.3 2010/05/16 02:25:48 sarrazip Exp $
     IngredientGroup.h - Group of sprites representing an "ingredient"
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2001-2009 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2001-2010 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -49,10 +49,10 @@ public:
 
     IngredientGroup(int yTarget, bool topBun);
     /*  Constructs an empty group that has the given vertical target.
-	The vertical target is the position where the group's member
-	sprites must stop falling.
-	'topBun' indicates if this group represents a top bun.
-	See the method isTopBun().
+        The vertical target is the position where the group's member
+        sprites must stop falling.
+        'topBun' indicates if this group represents a top bun.
+        See the method isTopBun().
     */
 
     ~IngredientGroup();
@@ -65,96 +65,96 @@ public:
 
     IngredientSprite *getMember(size_t index) const
     {
-	assert(index < 4);
-	assert(members[index] != NULL);
-	return members[index];
+        assert(index < 4);
+        assert(members[index] != NULL);
+        return members[index];
     }
 
     size_t getNumMembers() const
     {
-	return 4;
+        return 4;
     }
 
     bool areAllMembersLowered() const;
 
     void startFalling(int speedFactor, int numOfFloorsToGo = 1);
     /*  Gives an downward speed of 'speedFactor' to the sprites of this group
-	and to the sprites of the carried enemies.
-	Puts this group in the FALL1 state.
-	'numOfFloorsToGo' must be the number of floors that must be
-	travelled by this group.
+        and to the sprites of the carried enemies.
+        Puts this group in the FALL1 state.
+        'numOfFloorsToGo' must be the number of floors that must be
+        travelled by this group.
     */
 
     State getState() const { return state; }
 
     void bounce(int speedFactor);
     /*  Gives an upward speed of 'speedFactor' to the sprites of this group
-	and to the sprites of the carried enemies.
-	Puts this group in the BOUNCE state and sets the bounce time
-	to a positive number of ticks.
+        and to the sprites of the carried enemies.
+        Puts this group in the BOUNCE state and sets the bounce time
+        to a positive number of ticks.
     */
 
     void stall();
     /*  Stops the sprites of this group and the sprites of the carried enemies.
-	Puts this group in the STALL state and sets the stall time
-	to a positive number of ticks.
+        Puts this group in the STALL state and sets the stall time
+        to a positive number of ticks.
     */
 
     void fallBack(int speedFactor);
     /*  Gives an downward speed of 'speedFactor' to the sprites of this group
-	and to the sprites of the carried enemies.
-	Puts this group in the FALL2 state.
+        and to the sprites of the carried enemies.
+        Puts this group in the FALL2 state.
     */
 
     void fallToNextFloor(int speedFactor);
     /*  Gives an downward speed of 'speedFactor' to the sprites of this group
-	and to the sprites of the carried enemies.
-	Puts this group in the FALL1 state.
+        and to the sprites of the carried enemies.
+        Puts this group in the FALL1 state.
     */
 
     void stop();
     /*  Sets the speed of all members to zero.
-	Makes all members normal (i.e., not lowered).
-	Aligns all members of the vertical position of the first member.
+        Makes all members normal (i.e., not lowered).
+        Aligns all members of the vertical position of the first member.
     */
 
     int  getVerticalTarget() const { return verticalTarget; }
 
     void addCarriedEnemy(EnemySprite *s);
     /*  Adds 's' to this group's list of carried enemies.
-	Tells 's' that this group is its carrying group.
+        Tells 's' that this group is its carrying group.
     */
-    
+
     const flatzebra::SpriteList &getCarriedEnemies() const { return carriedEnemies; }
     flatzebra::SpriteList &getCarriedEnemies() { return carriedEnemies; }
     void clearCarriedEnemies() { carriedEnemies.clear(); }
 
     int getBounceTime() const { return bounceTime; }
     int decBounceTime()
-	    { if (bounceTime != 0) bounceTime--; return bounceTime; }
+            { if (bounceTime != 0) bounceTime--; return bounceTime; }
     int getStallTime() const { return stallTime; }
     int decStallTime()
-	    { if (stallTime != 0) stallTime--; return stallTime; }
+            { if (stallTime != 0) stallTime--; return stallTime; }
 
     void   setNumFloorsToGo(size_t n) { numFloorsToGo = n; }
     size_t getNumFloorsToGo() const { return numFloorsToGo; }
     size_t decNumFloorsToGo()
-	    { if (numFloorsToGo != 0) numFloorsToGo--; return numFloorsToGo; }
+            { if (numFloorsToGo != 0) numFloorsToGo--; return numFloorsToGo; }
     flatzebra::Couple getCenterPos() const;
 
     bool isTopBun() const { return topBunFlag; }
     /*  Indicates if this group represents a top bun.
-	When a top bun reaches the plate, the corresponding hamburger
-	is done.  When all hamburgers are done, the level is done.
+        When a top bun reaches the plate, the corresponding hamburger
+        is done.  When all hamburgers are done, the level is done.
     */
 
     void restore(int bounceTime, int stallTime,
-			    State state, size_t numFloorsToGo)
+                            State state, size_t numFloorsToGo)
     {
-	this->bounceTime = bounceTime;
-	this->stallTime = stallTime;
-	this->state = state;
-	this->numFloorsToGo = numFloorsToGo;
+        this->bounceTime = bounceTime;
+        this->stallTime = stallTime;
+        this->state = state;
+        this->numFloorsToGo = numFloorsToGo;
     }
 
 private:
@@ -168,6 +168,10 @@ private:
     size_t numFloorsToGo;
     bool topBunFlag;
 
+    // Forbidden operations:
+    IngredientGroup(const IngredientGroup &);
+    IngredientGroup &operator = (const IngredientGroup &);
+
 };
 
 
